info = {
    "name": "as",
    "date_order": "YMD",
    "january": [
        "জানু",
        "জানুৱাৰী"
    ],
    "february": [
        "ফেব্ৰু",
        "ফেব্ৰুৱাৰী"
    ],
    "march": [
        "মাৰ্চ"
    ],
    "april": [
        "এপ্ৰিল"
    ],
    "may": [
        "মে"
    ],
    "june": [
        "জুন"
    ],
    "july": [
        "জুলাই"
    ],
    "august": [
        "আগ",
        "আগষ্ট"
    ],
    "september": [
        "ছেপ্তেম্বৰ",
        "সেপ্ট"
    ],
    "october": [
        "অক্টো",
        "অক্টোবৰ"
    ],
    "november": [
        "নভে",
        "নৱেম্বৰ"
    ],
    "december": [
        "ডিচেম্বৰ",
        "ডিসে"
    ],
    "monday": [
        "সোম",
        "সোমবাৰ"
    ],
    "tuesday": [
        "মঙ্গল",
        "মঙ্গলবাৰ"
    ],
    "wednesday": [
        "বুধ",
        "বুধবাৰ"
    ],
    "thursday": [
        "বৃহষ্পতি",
        "বৃহষ্পতিবাৰ"
    ],
    "friday": [
        "শুক্ৰ",
        "শুক্ৰবাৰ"
    ],
    "saturday": [
        "শনি",
        "শনিবাৰ"
    ],
    "sunday": [
        "দেওবাৰ",
        "ৰবি"
    ],
    "am": [
        "পূৰ্বাহ্ণ"
    ],
    "pm": [
        "অপৰাহ্ণ"
    ],
    "year": [
        "বছৰ"
    ],
    "month": [
        "মাহ"
    ],
    "week": [
        "সপ্তাহ"
    ],
    "day": [
        "দিন"
    ],
    "hour": [
        "ঘণ্টা"
    ],
    "minute": [
        "মিনিট"
    ],
    "second": [
        "ছেকেণ্ড"
    ],
    "relative-type": {
        "0 day ago": [
            "আজি"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "কালি"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "কাইলৈ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
